==> react-ui-library-0.9.0.tgz: package/src/components/Button.js <==
import React, { PropTypes } from 'react'
import { css } from 'glamor'
import cx from 'classnames'
import Box from './Box'
import theme from './theme'
const { majorScale } = theme

const nakedStyle = () => css({
  backgroundColor: 'transparent',
  '&:hover': {
    backgroundColor: theme.colors.tint[1]
  },
  '&:active': {
    backgroundColor: theme.colors.tint[2]
  }
})

const intentStateStyle = intentState => ({
  backgroundColor: intentState.backgroundColor,
  color: intentState.textColor,
  ...(intentState.boxShadow ? {
    boxShadow: intentState.boxShadow
  } : {})
})

const intentStyle = intent => ({
  ...intentStateStyle(intent.default),
  '&:hover': {
    ...intentStateStyle(intent.hover)
  },
  '&:focus': {
    ...intentStateStyle(intent.focus)
  },
  '&:active': {
    ...intentStateStyle(intent.active)
  }
})

const getStyle = ({ primary, secondary, danger, naked }) => {
  if (primary) return css(intentStyle(theme.intent['primary']))
  if (danger) return css(intentStyle(theme.intent['danger']))
  if (naked) return css(nakedStyle())
  if (secondary) return css(intentStyle(theme.intent['secondary'])) /* default */
  return ''
}

const baseStyles = css({
  textTransform: 'capitalize',
  border: 0,
  fontWeight: 400,
  textDecoration: 'none',
  transition: theme.animationDuration.faster,
  transitionProperty: 'background-color, color, box-shadow, opacity',
  cursor: 'pointer',
  whiteSpace: 'nowrap',
  userSelect: 'none',
  '&:active, &:focus': {
    outline: 'none'
  }
})

const parseProps = ({
  className,
  primary,
  secondary,
  danger,
  naked,
  ...props
}) => ({
  className: cx(`${baseStyles}`, `${getStyle({ primary, secondary, danger, naked })}`, className),
  ...props
})

const Button = props => <Box {...parseProps(props)} />

Button.propTypes = {
  ...Box.propTypes,
  primary: PropTypes.bool,
  secondary: PropTypes.bool,
  danger: PropTypes.bool,
  naked: PropTypes.bool
}

Button.defaultProps = {
  is: 'button',
  display: 'inline-block',
  textAlign: 'center',
  secondary: true,
  rounded: true,
  paddingX: majorScale(3),
  paddingY: majorScale(1),
  textStyle: 'body1'
}

Button.displayName = 'Button'

export default Button

==> react-ui-library-2.0.1.tgz: package/src/components/Button.js <==
import React, { PropTypes } from 'react'
import { css } from 'glamor'
import cx from 'classnames'
import Box from './Box'
import theme from './theme'
const { majorScale } = theme

const nakedStyle = () => css({
  backgroundColor: 'transparent',
  '&:hover': {
    backgroundColor: theme.colors.tint[1]
  },
  '&:active': {
    backgroundColor: theme.colors.tint[2]
  }
})

const intentStateStyle = intentState => ({
  backgroundColor: intentState.backgroundColor,
  color: intentState.textColor,
  ...(intentState.boxShadow ? {
    boxShadow: intentState.boxShadow
  } : {})
})

const intentStyle = intent => ({
  ...intentStateStyle(intent.default),
  '&:hover': {
    ...intentStateStyle(intent.hover)
  },
  '&:focus': {
    ...intentStateStyle(intent.focus)
  },
  '&:active': {
    ...intentStateStyle(intent.active)
  }
})

const getStyle = ({ primary, secondary, danger, naked }) => {
  if (primary) return css(intentStyle(theme.intent['primary']))
  if (danger) return css(intentStyle(theme.intent['danger']))
  if (naked) {
    console.warning('react-ui-library: <Button naked /> naked styling will be deprecated.')
    return css(nakedStyle())
  }
  if (secondary) return css(intentStyle(theme.intent['secondary'])) /* default */
  return ''
}

const baseStyles = css({
  textTransform: 'capitalize',
  border: 0,
  fontWeight: 400,
  textDecoration: 'none',
  transition: theme.animationDuration.faster,
  transitionProperty: 'background-color, color, box-shadow, opacity',
  cursor: 'pointer',
  whiteSpace: 'nowrap',
  userSelect: 'none',
  '&:active, &:focus': {
    outline: 'none'
  }
})

const parseProps = ({
  className,
  primary,
  secondary,
  danger,
  naked,
  ...props
}) => ({
  className: cx(`${baseStyles}`, `${getStyle({ primary, secondary, danger, naked })}`, className),
  ...props
})

const Button = props => <Box {...parseProps(props)} />

Button.propTypes = {
  ...Box.propTypes,
  primary: PropTypes.bool,
  secondary: PropTypes.bool,
  danger: PropTypes.bool,
  naked: PropTypes.bool
}

Button.defaultProps = {
  is: 'button',
  display: 'inline-block',
  textAlign: 'center',
  secondary: true,
  rounded: true,
  paddingX: majorScale(3),
  paddingY: majorScale(1),
  textStyle: 'body1'
}

Button.displayName = 'Button'

export default Button
